/*-----------------------------------------------------------------
  All code is provided for EDUCATIONAL purposes ONLY. There is no
  warranty and no support.

  Copyright (c) Jack Botner and licensed under the MIT license; see
  http://opensource.org/licenses/mit-license.php

  appltimer by Jack Botner

  appltimer.h
-----------------------------------------------------------------*/
#ifndef _APPLTIMER_H_
#define _APPLTIMER_H_

#include "common.h"

#define INIT_TIMER0			( 256 - 250 )
#define INIT_TIMER1			( 65536 - 10417 )
#define INIT_TIMER2			( 256 - 250 )

#define MAX_CHECKS       	10		// number of tests before a switch is debounced

#define LCD_MAINT_INTERVAL_SECS		9000	// 2.5 hours

// System modes bits
#define MODE_RUN			1
#define MODE_PROGRAM		2

// Main Menu Indexes
#define INDEX_RUN			0
#define INDEX_ACTIVATE		1
#define INDEX_SETCLK		2
#define INDEX_SETON			3
#define INDEX_SETOFF		4
#define INDEX_PREPGM		5
#define INDEX_CLKTEST		6

// Events bits (flags 1)
#define EVENT_UPDATE_LCD		0
#define EVENT_ANALYZE_STATE		1
#define EVENT_CONVERT_TEMP		2
#define EVENT_UPDATE_EEPROM		3
#define EVENT_BUTTON_PRESSED	4
#define EVENT_ENCODER_UP		5
#define EVENT_ENCODER_DOWN		6
#define EVENT_READ_RTC			7

// Events bits (flags 2)
#define EVENT_SET_RTC			0
#define EVENT_LCD_MAINT			1

// Debounced switches bits
#define ENC_SWITCH_A			0
#define ENC_SWITCH_B			1
#define ENC_SWITCH_PB			2

// Rotary encoder port defines
#define ENCODER_PORT			PINB
#define ENCODER_A				PINB1
#define ENCODER_B				PINB0
#define ENCODER_PB				PINB2

// Relay port defines
#define RELAY_PORT_OUT			PORTD
#define RELAY_PORT_IN			PIND
#define RELAY_PIN				PORTD7

// Program Time parameters
#define ONTIME				1
#define OFFTIME				2

// Activated flag defines
#define ACTIVATED_YES		1
#define ACTIVATED_NO		0

// EEPROM stuff
typedef struct _MY_EEPROM_DATA
{
  uint8_t	ucOnTimeHH;
  uint8_t	ucOnTimeMM;
  uint8_t	ucOffTimeHH;
  uint8_t	ucOffTimeMM;
  uint8_t	ucActivated;			// timer is activated
  uint8_t   ucPreprogram;			// preset program is active
}
MY_EEPROM_DATA;

// Functions

void program_clock( void );
void program_time( uint8_t ucRequest );

#endif  //_MAIN_H_
